==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+220"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / preto
Preto</translatorcomment>
        <translation>Preto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / preto
Branco</translatorcomment>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Idioma para Comando:
Idioma para os Comandos:
Idioma GUI:</translatorcomment>
        <translation>Linguagem:</translation>
    </message>
    <message>
        <source>Welcome to QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bem-vindo ao QCAD</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>%1 First Start</source>
        <translation>%1 primeiro iniciar</translation>
    </message>
    <message>
        <location line="+191"/>
        <source>Welcome to %1</source>
        <translation>Bem-vindo ao %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Por favor, escolha as configurações usadas para novos desenhos. Todas essas configurações podem ser alteradas posteriormente no diálogo preferências.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Unidade Padrão:
&amp;Principal unidade do desenho:</translatorcomment>
        <translation>Unidades:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho de papel padrão:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--exact match--
--file: Input_pt.ts--
Ponto decimal:</translatorcomment>
        <translation>Ponto decimal:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--ignored case--
--file: pt.po--
Cor de plano de fundo</translatorcomment>
        <translation>Cor de plano de fundo:</translation>
    </message>
    <message>
        <source>QCAD First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD primeiro iniciar</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+246"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / preto
Preto</translatorcomment>
        <translation>Preto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / preto
Branco</translatorcomment>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Idioma para Comando:
Idioma para os Comandos:
Idioma GUI:</translatorcomment>
        <translation>Linguagem:</translation>
    </message>
    <message>
        <source>Welcome to QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bem-vindo ao QCAD</translation>
    </message>
    <message>
        <location line="-217"/>
        <location line="+216"/>
        <source>%1 First Start</source>
        <translation>%1 Primeiro Início</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Welcome to %1</source>
        <translation>Bem-vindo ao %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Por favor, escolha as configurações usadas para novos desenhos. Todas essas configurações podem ser alteradas posteriormente no Diálogo de Preferências.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Unidade Padrão:
&amp;Principal unidade do desenho:</translatorcomment>
        <translation>Unidade:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho de Papel Padrão:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--exact match--
--file: Input_pt.ts--
Ponto decimal:</translatorcomment>
        <translation>Ponto Decimal:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--ignored case--
--file: pt.po--
Cor de plano de fundo</translatorcomment>
        <translation>Cor do Pano de Fundo:</translation>
    </message>
    <message>
        <source>QCAD First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD primeiro iniciar</translation>
    </message>
</context>
</TS>
